==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/INVOICEVOUCHERCOSTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVOICEVOUCHERCOSTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INVOICEVOUCHERCOSTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IVDTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GLCODECOMBINATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVOICEVOUCHERCOSTID_Type", propOrder = {
    "invoiceid",
    "ivdtype",
    "glcodecombinationid"
})
public class INVOICEVOUCHERCOSTID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "IVDTYPE", required = true)
    protected TYPE_Type ivdtype;
    @XmlElement(name = "GLCODECOMBINATIONID", required = true)
    protected GLCODECOMBINATIONID_Type glcodecombinationid;

    /**
     * Gets the value of the invoiceid property.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Sets the value of the invoiceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Gets the value of the ivdtype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getIVDTYPE() {
        return ivdtype;
    }

    /**
     * Sets the value of the ivdtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setIVDTYPE(TYPE_Type value) {
        this.ivdtype = value;
    }

    /**
     * Gets the value of the glcodecombinationid property.
     * 
     * @return
     *     possible object is
     *     {@link GLCODECOMBINATIONID_Type }
     *     
     */
    public GLCODECOMBINATIONID_Type getGLCODECOMBINATIONID() {
        return glcodecombinationid;
    }

    /**
     * Sets the value of the glcodecombinationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GLCODECOMBINATIONID_Type }
     *     
     */
    public void setGLCODECOMBINATIONID(GLCODECOMBINATIONID_Type value) {
        this.glcodecombinationid = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/INVOICEVOUCHERCOSTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INVOICEVOUCHERCOSTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INVOICEVOUCHERCOSTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}IVDTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GLCODECOMBINATIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVOICEVOUCHERCOSTID_Type", propOrder = {
    "invoiceid",
    "ivdtype",
    "glcodecombinationid"
})
public class INVOICEVOUCHERCOSTID_Type {

    @XmlElement(name = "INVOICEID", required = true)
    protected INVOICEID_Type invoiceid;
    @XmlElement(name = "IVDTYPE", required = true)
    protected TYPE_Type ivdtype;
    @XmlElement(name = "GLCODECOMBINATIONID", required = true)
    protected GLCODECOMBINATIONID_Type glcodecombinationid;

    /**
     * Obtient la valeur de la propriété invoiceid.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEID_Type }
     *     
     */
    public INVOICEID_Type getINVOICEID() {
        return invoiceid;
    }

    /**
     * Définit la valeur de la propriété invoiceid.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEID_Type }
     *     
     */
    public void setINVOICEID(INVOICEID_Type value) {
        this.invoiceid = value;
    }

    /**
     * Obtient la valeur de la propriété ivdtype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getIVDTYPE() {
        return ivdtype;
    }

    /**
     * Définit la valeur de la propriété ivdtype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setIVDTYPE(TYPE_Type value) {
        this.ivdtype = value;
    }

    /**
     * Obtient la valeur de la propriété glcodecombinationid.
     * 
     * @return
     *     possible object is
     *     {@link GLCODECOMBINATIONID_Type }
     *     
     */
    public GLCODECOMBINATIONID_Type getGLCODECOMBINATIONID() {
        return glcodecombinationid;
    }

    /**
     * Définit la valeur de la propriété glcodecombinationid.
     * 
     * @param value
     *     allowed object is
     *     {@link GLCODECOMBINATIONID_Type }
     *     
     */
    public void setGLCODECOMBINATIONID(GLCODECOMBINATIONID_Type value) {
        this.glcodecombinationid = value;
    }

}
